==> qtop_2.2.5.orig.tar.gz: Top-2.2.5/base-qt/XmlOption.h <==
#ifndef XmlOption_h
#define XmlOption_h

// $Id: XmlOption.h,v 1.17 2014/08/04 22:41:29 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QDomDocument>
#include <QDomElement>
#include <QString>

#include "Option.h"

namespace Base
{
    //! some XML definitions specific to Option management
    namespace Xml
    {

        static const QString SpecialOption = "SpecialOption";
        static const QString Option = "Option";
        static const QString Options = "Options";
        static const QString Value = "Value";

    }

}

//! Xml implementation of the Option object
class XmlOption:public Option
{

    public:

    //! constructor
    XmlOption( const QString& name, const Option& option ):
        Option( option ),
        name_( name )
    {}

    //! constructor from DOM node
    XmlOption( const QDomElement& );

    //! create dom element
    QDomElement domElement( QDomDocument& ) const;

    //! name
    void setName( const QString& value )
    { name_ = value; }

    //! name
    const QString& name( void ) const
    { return name_; }

    private:

    //! option name
    QString name_;

};

#endif

==> qtop_2.3.1.orig.tar.gz: Top-2.3.1/base-qt/XmlOption.h <==
#ifndef XmlOption_h
#define XmlOption_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QDomDocument>
#include <QDomElement>
#include <QString>

#include "Option.h"

namespace Base
{
    //* some XML definitions specific to Option management
    namespace Xml
    {

        static const QString SpecialOption = "SpecialOption";
        static const QString Option = "Option";
        static const QString Options = "Options";
        static const QString Value = "Value";

    }

}

//* Xml implementation of the Option object
class XmlOption:public Option
{

    public:

    //* constructor
    XmlOption( const QString& name, const Option& option ):
        Option( option ),
        name_( name )
    {}

    //* constructor from DOM node
    XmlOption( const QDomElement& );

    //* create dom element
    QDomElement domElement( QDomDocument& ) const;

    //* name
    void setName( const QString& value )
    { name_ = value; }

    //* name
    const QString& name( void ) const
    { return name_; }

    private:

    //* option name
    QString name_;

};

#endif
